Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Kloner ¶
type Kloner struct {
// contains filtered or unexported fields
}
func (*Kloner) Clone ¶
This is the logic that defins a Clone() for a Go repository Of course we need to check out into $GOPATH
func (*Kloner) DeleteRemote ¶
func (*Kloner) GetCloneDirectory ¶
repoToCloneDirectory will take a repository and reason about where to check out the repository on your local filesystem
Click to show internal directories.
Click to hide internal directories.